#
# spec file for package speexdsp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define libname lib%{name}%{sover}
Name:           speexdsp
Version:        1.2.1
Release:        2.5
Summary:        Patent free speech codec
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://www.speex.org/
#Git-Clone:     https://github.com/xiph/speexdsp
Source0:        https://github.com/xiph/speexdsp/archive/refs/tags/SpeexDSP-%{version}.tar.gz
Source2:        baselibs.conf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(ogg)
Conflicts:      speex <= 1.1.999_1.2rc1

%description
Speex is a patent free audio codec designed especially for voice
(unlike Vorbis which targets general audio) signals and providing good
narrowband and wideband quality. This project aims to be complementary
to the Vorbis codec.

%package -n %{libname}
Summary:        Patent-free speech codec
Group:          System/Libraries

%description -n %{libname}
Speex is a patent free audio codec designed especially for voice
(unlike Vorbis which targets general audio) signals and providing good
narrowband and wideband quality. This project aims to be complementary
to the Vorbis codec.

%package devel
Summary:        Development package for SpeeX
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Conflicts:      pkgconfig(speex) <= 1.1.999_1.2rc1
License:        BSD-3-Clause AND GFDL-1.1-or-later

%description devel
This package contains the files needed to compile programs that use the
SpeeX library.

%prep
%autosetup -n speexdsp-SpeexDSP-%{version}

%build
./autogen.sh
# Disable NEON since it doesn't check for availability of the NEON
# extension at runtime
%configure \
  --disable-static \
  --disable-neon
%make_build

%install
%make_install
# remove unneeded *.la files
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%{_libdir}/libspeexdsp.so.%{sover}*

%files devel
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/manual.pdf
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Apr 24 2023 Frederic Crozat <fcrozat@suse.com>
- Ensure COPYING is shipped as license file
- Add license tag to devel package.
* Sat Jun 18 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * CI: add gitlab CI integration
  * fixed-point: Remove unused MULT16_32_Q1[1-4] macros and inlines
  * fixed-point: don't truncate 32-bit arg to MULT16_32_Q15
  * fixed-point resample: remove 1-bit shift right before interpolation
  * fixed-point: introduce MULT16_32_32 to handle unexpected types in MULT16_32_Q15
  * Fix incorrect macro names in arch.h
  * Remove unused stack_alloc.h
  * autotools: do not use deprecated macros
* Thu Jan 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update dependencies and update spec file
* Sun Sep  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * No changelog provided
- Drop speexdsp-fixbuilds-774c87d.patch (merged)
* Mon Oct  2 2017 mpluskal@suse.com
- Some packaging cleanup with spec-cleaner
* Mon May 18 2015 mpluskal@suse.com
- Fix incorrect includes (boo#929450)
  * speexdsp-fixbuilds-774c87d.patch
* Sun Apr  5 2015 dmueller@suse.com
- disable unchecked use of NEON extension
* Mon Mar 16 2015 jengelh@inai.de
- Use the tilde versioning scheme (like the "speex" package).
  Improve group classification.
* Sat Feb 28 2015 tchvatal@suse.com
- Define libname to have the declaration only on one line
- Align the Conflict lines
* Mon Feb 23 2015 mpluskal@suse.com
- Split package to two separate packages
  * speexdsp contains libraries
  * speex contains tools
- Update to 1.2rc3:
  * no upstream changelog provided
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Nov 24 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep  3 2010 cristian.rodriguez@opensuse.org
- Do not include build date in binaries...
* Fri Jun 25 2010 dmueller@suse.de
- obsolete old -XXbit packages
* Thu Jan 14 2010 chris@computersalat.de
- fix build for SLE_10
  autoreconf for suse_version >= 1100
- spec
  o sort TAGS
  o macros
    rm > {__rm}
    version > {version} ....
* Thu Jan  7 2010 lnussel@suse.de
- split off libspeex1 and libspeexdsp1 according to library
  packaging policy
- include actual tarball version in package version
- don't package README's for embedded cpus
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Aug  6 2008 tiwai@suse.de
- updated to version 1.2rc1:
  * support for acoustic echo cancellation with multiple mics
    and speakers.
  * add an API to decorrelate loudspeaker signals
  * fixes for a few bugs in the echo canceller, jitter buffer and
    preprocessor
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 1.2beta3:
  * all the non-codec components (preprocessor, echo cancellation,
    jitter buffer) have been moved to a new libspeexdsp library
  * a new jitter buffer algorithm
  * resampler improvements/fixes
  * libspeex can be built without any floating point support
* Tue Aug 14 2007 tiwai@suse.de
- fix the bug in resampler code (signed/unsigned mismatch)
- move man pages to the main package
- a bit clean up of spec file
* Thu May 24 2007 tiwai@suse.de
- updated to version 1.2beta2:
  * reduced RAM requirement
  * A new resampler module
  * improved / fixed echo canceller
  * improved preprocessor
  * early TriMedia support (incomplete)
- removed static library and *.la files
* Tue Apr 10 2007 tiwai@suse.de
- split shared library to libspeex sub package.
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 1.2beta1:
  * Improvement of encoder/decoder quality
  * Enhander improvements (now on by default)
  * Input/output high-pass filters
  * Fixing minor regressions in previous 1.1.x releases
  * Reduced memory usage
  * Reduced CPU usage
* Wed Aug  9 2006 sbrabec@suse.cz
- Updated to version 1.1.12:
  * echo canceller converted to fixed-point
  * Improvements to the experimental Vorbis-based masking model
  * several bug fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct  4 2005 tiwai@suse.de
- fix the type-punning.
- add check of return value from fread().
* Tue Jun 14 2005 tiwai@suse.de
- updated to version 1.0.5.
* Thu Sep 16 2004 tiwai@suse.de
- fixed speex.m4 for the recent autoconf.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 1.0.4.
* Mon Jan 12 2004 adrian@suse.de
- add %%defattr
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.0.3.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 1.0.1.
* Mon Jun  2 2003 ro@suse.de
- remove unpackaged files from buildroot
* Thu Mar 27 2003 tiwai@suse.de
- updated to version 1.0 final.
* Thu Jan 30 2003 tiwai@suse.de
- updated to version 1.0rc2.
* Fri Jan 17 2003 tiwai@suse.de
- updated to version 1.0rc1.
* Wed Nov 27 2002 tiwai@suse.de
- initial version: 1.0beta3
